--[[
	Computes the position of a layer named "Target", and rotates the attached layer so that it faces the target at all times.
]]

function LayerScript(moho)
	if (moho.frame == 0) then
		return
	end

	local targetLayer = moho.document:LayerByName("Target")
	if (targetLayer == nil) then
		print("Target layer not found.")
		return
	end

	local origin = LM.Vector3:new_local()
	local target = LM.Vector3:new_local()
	local matrix = LM.Matrix:new_local()

	moho.layer:GetFullTransform(moho.frame, matrix, nil)
	local o = moho.layer:Origin()
	origin:Set(o.x, o.y, 0)
	matrix:Transform(origin)

	targetLayer:GetFullTransform(moho.frame, matrix, nil)
	local o = targetLayer:Origin()
	target:Set(o.x, o.y, 0)
	matrix:Transform(target)

	local v = target - origin
	moho.layer.fRotationY.value = math.atan2(v.x, v.z)
	moho.layer.fRotationX.value = -math.atan2(v.y, math.sqrt(v.x * v.x + v.z * v.z))
end
